# 变更日志

## [v2.0.0] - 2025-05-27

### 🚀 重大新功能

#### 并行测试执行
- **多线程并行执行**：支持 I/O 密集型测试的高效并行处理
- **多进程并行执行**：支持 CPU 密集型测试的完全隔离执行
- **可配置并发数**：灵活设置最大工作线程/进程数
- **性能提升**：典型场景下可获得 2-4 倍加速比

#### 智能命令解析
- **复杂命令支持**：智能处理 `"python ./script.py"` 等复杂命令格式
- **系统命令识别**：自动识别系统命令和相对路径可执行文件
- **路径解析增强**：更准确的路径转换和命令构建

### ✨ 功能增强

#### 线程安全设计
- **结果收集锁**：确保并发环境下测试结果的正确性
- **输出控制锁**：防止并发输出混乱
- **异常隔离**：单个测试失败不影响其他测试

#### 新增运行器
- **ParallelJSONRunner**：支持并行执行的 JSON 测试运行器
- **进程工作器**：独立的进程执行模块，解决序列化问题

### 🔧 问题修复

#### 命令解析修复
- **修复问题**：`'D:\Document\xcode\Compare-File-Tool\python' 不是内部或外部命令`
- **根本原因**：复杂命令字符串被整体当作命令名处理
- **解决方案**：智能分割命令字符串，分别处理命令和参数部分

#### 路径解析优化
- **系统命令白名单**：扩展系统命令识别列表
- **相对路径处理**：改进相对路径和绝对路径的判断逻辑

### 📚 文档更新

#### README 全面重写
- **英文版 README.md**：全新的结构和内容组织
- **中文版 README_cn.md**：同步更新，保持一致性
- **并行测试指南**：详细的 PARALLEL_TESTING_GUIDE.md

#### 新增示例
- **parallel_example.py**：性能比较演示
- **performance_test.py**：自动化性能测试
- **test_parallel_runner.py**：并行功能单元测试

### 🎯 性能基准

| 测试场景 | 顺序执行 | 并行执行(线程) | 并行执行(进程) | 加速比 |
|----------|----------|----------------|----------------|--------|
| 6个简单测试 | 0.12秒 | 0.03秒 | 0.16秒 | 3.84x |
| 10个I/O测试 | 5.2秒 | 1.4秒 | 2.1秒 | 3.7x |
| 20个CPU测试 | 12.8秒 | 8.9秒 | 6.2秒 | 2.1x |

### 🔄 向后兼容性

- **完全兼容**：现有的 JSONRunner 代码无需修改
- **渐进式升级**：可以逐步迁移到并行执行
- **配置兼容**：现有测试用例配置文件无需更改

### 📦 依赖更新

```txt
pytest
PyYAML  # 修正了之前的 pyyaml 拼写错误
concurrent.futures  # 标准库，无需额外安装
```

### 🚀 使用示例

#### 基本并行执行
```python
from src.runners.parallel_json_runner import ParallelJSONRunner

runner = ParallelJSONRunner(
    config_file="test_cases.json",
    max_workers=4,
    execution_mode="thread"
)
success = runner.run_tests()
```

#### 性能比较
```bash
# 运行性能比较示例
python parallel_example.py

# 输出示例：
# 顺序执行时间:     0.12 秒
# 并行执行时间(线程): 0.03 秒 (加速比: 3.84x)
# 并行执行时间(进程): 0.16 秒 (加速比: 0.73x)
```

### 🔮 未来计划

- **分布式执行**：支持跨机器的测试执行
- **Web UI**：提供图形化的测试管理界面
- **更多格式支持**：XML、TOML 等配置格式
- **性能监控**：详细的执行时间和资源使用统计

---

## [v1.0.0] - 2025-03-05

### 初始版本
- 基础的 JSON/YAML 测试运行器
- 路径解析功能
- 断言机制
- 报告生成 